@@ -7,6 +7,7 @@ import dolfin
 
 from .. import pyaml
 from ..util import SetattrInitMixin
+from .debug_probe import DebugProbe
 from .delayed_form import DelayedForm
 from .expr import CellFunctionFunction
 from .function_space_cache import FunctionSpaceCache
@@ -260,3 +261,8 @@ measures: tuple of :py:class:`.expr.DelayedForm`
 
     def element(self, name, *args, **kwargs):
         return dolfin.FiniteElement(name, self.ufl_cell, *args, **kwargs)
+
+    def get_debug_probe(self, quantity, space):
+        if isinstance(space, str):
+            space = getattr(self.space, space)
+        return DebugProbe(quantity, space, self.mesh_unit)
